Plots the conditional longitudinal expectations for a
new subject calculated using the dynLong function.
Usage
# S3 method for class 'dynLong'
plot(x, main = NULL, xlab = NULL, ylab = NULL, grid = TRUE, estimator, ...)Arguments
- x
an object of class
dynLongcalculated by thedynLongfunction.- main
an overall title for the plot: see
title.- xlab
a title for the x [time] axis: see
title.- ylab
a character vector of the titles for the K longitudinal outcomes y-axes: see
title.- grid
adds a rectangular grid to an existing plot: see
grid.- estimator
a character string that can take values
meanormedianto specify what prediction statistic is plotted from an objecting inheritting of classdynSurv. Default isestimator='median'. This argument is ignored for non-simulateddynSurvobjects, i.e. those oftype='first-order', as in that case a mode-based prediction is plotted.- ...
additional plotting arguments; currently limited to
lwdandcex. Seeparfor details.
References
Rizopoulos D. Dynamic predictions and prospective accuracy in joint models for longitudinal and time-to-event data. Biometrics. 2011; 67: 819–829.
Author
Graeme L. Hickey (graemeleehickey@gmail.com)
Examples
if (FALSE) { # \dontrun{
# Fit a joint model with bivariate longitudinal outcomes
data(heart.valve)
hvd <- heart.valve[!is.na(heart.valve$log.grad) & !is.na(heart.valve$log.lvmi), ]
fit2 <- mjoint(
formLongFixed = list("grad" = log.grad ~ time + sex + hs,
"lvmi" = log.lvmi ~ time + sex),
formLongRandom = list("grad" = ~ 1 | num,
"lvmi" = ~ time | num),
formSurv = Surv(fuyrs, status) ~ age,
data = list(hvd, hvd),
inits = list("gamma" = c(0.11, 1.51, 0.80)),
timeVar = "time",
verbose = TRUE)
hvd2 <- droplevels(hvd[hvd$num == 1, ])
out <- dynLong(fit2, hvd2)
plot(out, main = "Patient 1")
} # }