Displays a plot of the BLUPs and approximate 95% prediction interval for each subject.
Usage
# S3 method for class 'ranef.mjoint'
plot(x, ...)Value
an object inheriting from class ggplot, which displays a
trellis plot with a separate panel for each effect, showing a dotplot (with
optional error bars indicating approximate 95% prediction intervals if the
argument postVar=TRUE is set in the call to
ranef) for each subject (by row).
References
Pinheiro JC, Bates DM. Mixed-Effects Models in S and S-PLUS. New York: Springer Verlag; 2000.
Author
Graeme L. Hickey (graemeleehickey@gmail.com)
Examples
if (FALSE) { # \dontrun{
require(ggplot2)
data(heart.valve)
hvd <- heart.valve[!is.na(heart.valve$log.grad) & !is.na(heart.valve$log.lvmi), ]
set.seed(1)
fit1 <- mjoint(formLongFixed = log.lvmi ~ time,
formLongRandom = ~ time | num,
formSurv = Surv(fuyrs, status) ~ 1,
data = hvd,
timeVar = "time")
plot(ranef(fit1, postVar = TRUE))
} # }