Fits the joint model proposed by Henderson and colleagues (2000) tools:::Rd_expr_doi("10.1093/biostatistics/1.4.465"), but extended to the case of multiple continuous longitudinal measures. The time-to-event data is modelled using a Cox proportional hazards regression model with time-varying covariates. The multiple longitudinal outcomes are modelled using a multivariate version of the Laird and Ware linear mixed model. The association is captured by a multivariate latent Gaussian process. The model is estimated using a Monte Carlo Expectation Maximization algorithm. This project was funded by the Medical Research Council (Grant number MR/M013227/1).
Maintainer: Graeme L. Hickey [email protected] (ORCID)
Authors:
Pete Philipson [email protected] (ORCID)
Ruwanthi Kolamunnage-Dona [email protected] (ORCID)
Alessandro Gasparini [email protected] (ORCID)
Other contributors:
Andrea Jorgensen [email protected] (ORCID) [contributor]
Paula Williamson [email protected] (ORCID) [contributor]
Dimitris Rizopoulos [email protected] (data/renal.rda, R/hessian.R, R/vcov.R) [contributor, data contributor]
Medical Research Council (Grant number: MR/M013227/1) [funder]
Useful links: