Plot convergence time series for parameter vectors from an mjoint object
Source: R/plotConvergence.R
plotConvergence.RdPlot convergence time series for parameter vectors from an
mjoint object.
Arguments
- object
an object inheriting from class
mjointfor a joint model of time-to-event and multivariate longitudinal data.- params
a string indicating what parameters are to be shown. Options are
params='gamma'for the time-to-event sub-model covariate coefficients, including the latent association parameters;params='beta'for the longitudinal sub-model fixed effects coefficients;params='sigma2'for the residual error variances from the longitudinal sub-model;params='D'for the lower triangular matrix of the variance-covariance matrix of random effects;params='loglik'for the log-likelihood.- discard
logical; if
TRUEthen the 'burn-in' phase iterations of the MCEM algorithm are discarded. Default isdiscard=FALSE.
References
Wei GC, Tanner MA. A Monte Carlo implementation of the EM algorithm and the poor man's data augmentation algorithms. J Am Stat Assoc. 1990; 85(411): 699-704.
Author
Graeme L. Hickey (graemeleehickey@gmail.com)